==> ejc-settlementmanage-impl-3.0.0-20240628.063848-285-sources.jar: com/ejianc/business/settlementmanage/vo/SettlementApplicationsealVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 总包结算书用印申请-主表
 *
 * @author generator
 *
 */
public class SettlementApplicationsealVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.String agentName; // 经办人
    private java.lang.String departmentName; // 部门
    private java.lang.String contractName; // 合同名称
    private java.lang.String constructionArea; // 建筑面积
    private java.math.BigDecimal contractPrice; // 合同造价
    private java.math.BigDecimal settlementValue; // 结算总额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date actualCommencementDate; // 实际开工日期
    private java.lang.String actualCommencementDateStr;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date actualCompletionDate; // 实际竣工日期
    private java.lang.String actualCompletionDateStr;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date applyTime; // 申请时间
    private java.lang.String documentsCode; // 单据编码
    private java.lang.String remarks; // 备注
    private java.lang.String organisation; // 所属组织
    private java.lang.Long agentId; // 经办人id
    private java.lang.Long agentDepartment; // 经办人部门
    private java.lang.Long contractId; // 合同id
    private java.lang.String phone; // 联系电话
    private java.lang.String createTimeShow; // 创建时间文本显示
    private java.lang.String billStateStr; // 单据状态Str
    private java.lang.Long originalId;
    private BigDecimal settlementSubmissionValue; // 结算报送值
    private BigDecimal settlementEstimateValue; // 结算预估值
    private BigDecimal estimatedCost; // 预计成本
    private BigDecimal profit; // 利润
    private BigDecimal profitRate; // 利润率
    private BigDecimal targetResponsibilityMargin; // 目标责任书利润率%
    private BigDecimal estimatedAccomplishTargetSituation; // 预计完成目标情况%
    private String sealCause; // 用印事由
    private BigDecimal sealFrequency; // 用印次数
    private BigDecimal sealCopies; // 用印份数
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date outDate; // 借出日期
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date returnDate; // 归还日期
    private String companySeal; // 公司章
    private String legalSeal; // 法人代表章
    private String contractSeal; // 合同专用章
    private String partySeal; // 党委章
    private String  disciplineSeal; // 纪委章
    private String otherSeal; // 其他章
    private String sealMemo; // 其他章备注
    private String sealLend; // 印章借出
    private String sealType; // 印章种类
    private String appendixIncome; // 项目收入成本总体概况
    private String appendixCommitment; // 用印承诺
    private String appendixInventory; // 用印清单

    public String getAppendixIncome() {
        return appendixIncome;
    }

    public void setAppendixIncome(String appendixIncome) {
        this.appendixIncome = appendixIncome;
    }

    public String getAppendixCommitment() {
        return appendixCommitment;
    }

    public void setAppendixCommitment(String appendixCommitment) {
        this.appendixCommitment = appendixCommitment;
    }

    public String getAppendixInventory() {
        return appendixInventory;
    }

    public void setAppendixInventory(String appendixInventory) {
        this.appendixInventory = appendixInventory;
    }

    public BigDecimal getSettlementSubmissionValue() {
        return settlementSubmissionValue;
    }

    public void setSettlementSubmissionValue(BigDecimal settlementSubmissionValue) {
        this.settlementSubmissionValue = settlementSubmissionValue;
    }

    public BigDecimal getSettlementEstimateValue() {
        return settlementEstimateValue;
    }

    public void setSettlementEstimateValue(BigDecimal settlementEstimateValue) {
        this.settlementEstimateValue = settlementEstimateValue;
    }

    public BigDecimal getEstimatedCost() {
        return estimatedCost;
    }

    public void setEstimatedCost(BigDecimal estimatedCost) {
        this.estimatedCost = estimatedCost;
    }

    public BigDecimal getProfit() {
        return profit;
    }

    public void setProfit(BigDecimal profit) {
        this.profit = profit;
    }

    public BigDecimal getProfitRate() {
        return profitRate;
    }

    public void setProfitRate(BigDecimal profitRate) {
        this.profitRate = profitRate;
    }

    public BigDecimal getTargetResponsibilityMargin() {
        return targetResponsibilityMargin;
    }

    public void setTargetResponsibilityMargin(BigDecimal targetResponsibilityMargin) {
        this.targetResponsibilityMargin = targetResponsibilityMargin;
    }

    public BigDecimal getEstimatedAccomplishTargetSituation() {
        return estimatedAccomplishTargetSituation;
    }

    public void setEstimatedAccomplishTargetSituation(BigDecimal estimatedAccomplishTargetSituation) {
        this.estimatedAccomplishTargetSituation = estimatedAccomplishTargetSituation;
    }

    public String getSealCause() {
        return sealCause;
    }

    public void setSealCause(String sealCause) {
        this.sealCause = sealCause;
    }

    public BigDecimal getSealFrequency() {
        return sealFrequency;
    }

    public void setSealFrequency(BigDecimal sealFrequency) {
        this.sealFrequency = sealFrequency;
    }

    public BigDecimal getSealCopies() {
        return sealCopies;
    }

    public void setSealCopies(BigDecimal sealCopies) {
        this.sealCopies = sealCopies;
    }

    public Date getOutDate() {
        return outDate;
    }

    public void setOutDate(Date outDate) {
        this.outDate = outDate;
    }

    public Date getReturnDate() {
        return returnDate;
    }

    public void setReturnDate(Date returnDate) {
        this.returnDate = returnDate;
    }

    public String getCompanySeal() {
        return companySeal;
    }

    public void setCompanySeal(String companySeal) {
        this.companySeal = companySeal;
    }

    public String getLegalSeal() {
        return legalSeal;
    }

    public void setLegalSeal(String legalSeal) {
        this.legalSeal = legalSeal;
    }

    public String getContractSeal() {
        return contractSeal;
    }

    public void setContractSeal(String contractSeal) {
        this.contractSeal = contractSeal;
    }

    public String getPartySeal() {
        return partySeal;
    }

    public void setPartySeal(String partySeal) {
        this.partySeal = partySeal;
    }

    public String getDisciplineSeal() {
        return disciplineSeal;
    }

    public void setDisciplineSeal(String disciplineSeal) {
        this.disciplineSeal = disciplineSeal;
    }

    public String getOtherSeal() {
        return otherSeal;
    }

    public void setOtherSeal(String otherSeal) {
        this.otherSeal = otherSeal;
    }

    public String getSealMemo() {
        return sealMemo;
    }

    public void setSealMemo(String sealMemo) {
        this.sealMemo = sealMemo;
    }

    public String getSealLend() {
        return sealLend;
    }

    public void setSealLend(String sealLend) {
        this.sealLend = sealLend;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")

    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer

    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人
     */

    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 部门
     */
    public java.lang.String getDepartmentName() {
        return departmentName;
    }

    /**
     * 部门
     */
    public void setDepartmentName(java.lang.String departmentName) {
        this.departmentName = departmentName;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }

    public String getConstructionArea() {
        return constructionArea;
    }

    public void setConstructionArea(String constructionArea) {
        this.constructionArea = constructionArea;
    }

    /**
     * 合同造价
     */
    public java.math.BigDecimal getContractPrice() {
        return contractPrice;
    }

    /**
     * 合同造价
     */
    public void setContractPrice(java.math.BigDecimal contractPrice) {
        this.contractPrice = contractPrice;
    }
    /**
     * 结算总额
     */
    public java.math.BigDecimal getSettlementValue() {
        return settlementValue;
    }

    /**
     * 结算总额
     */
    public void setSettlementValue(java.math.BigDecimal settlementValue) {
        this.settlementValue = settlementValue;
    }
    /**
     * 实际开工日期
     */
    public java.util.Date getActualCommencementDate() {
        return actualCommencementDate;
    }

    /**
     * 实际开工日期
     */
    public void setActualCommencementDate(java.util.Date actualCommencementDate) {
        this.actualCommencementDate = actualCommencementDate;
    }
    /**
     * 实际竣工日期
     */
    public java.util.Date getActualCompletionDate() {
        return actualCompletionDate;
    }

    /**
     * 实际竣工日期
     */
    public void setActualCompletionDate(java.util.Date actualCompletionDate) {
        this.actualCompletionDate = actualCompletionDate;
    }
    /**
     * 申请时间
     */
    public java.util.Date getApplyTime() {
        return applyTime;
    }

    /**
     * 申请时间
     */
    public void setApplyTime(java.util.Date applyTime) {
        this.applyTime = applyTime;
    }
    /**
     * 单据编码
     */
    public java.lang.String getDocumentsCode() {
        return documentsCode;
    }

    /**
     * 单据编码
     */
    public void setDocumentsCode(java.lang.String documentsCode) {
        this.documentsCode = documentsCode;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 所属组织
     */
    public java.lang.String getOrganisation() {
        return organisation;
    }

    /**
     * 所属组织
     */
    public void setOrganisation(java.lang.String organisation) {
        this.organisation = organisation;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人部门
     */
    @ReferSerialTransfer(referCode="idm-dept")

    public java.lang.Long getAgentDepartment() {
        return agentDepartment;
    }

    /**
     * 经办人部门
     */
    @ReferDeserialTransfer

    public void setAgentDepartment(java.lang.Long agentDepartment) {
        this.agentDepartment = agentDepartment;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-incontract")

    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer

    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 联系电话
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系电话
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }

    public String getActualCommencementDateStr() {
        return actualCommencementDateStr;
    }

    public void setActualCommencementDateStr(String actualCommencementDateStr) {
        this.actualCommencementDateStr = actualCommencementDateStr;
    }

    public String getActualCompletionDateStr() {
        return actualCompletionDateStr;
    }

    public void setActualCompletionDateStr(String actualCompletionDateStr) {
        this.actualCompletionDateStr = actualCompletionDateStr;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }

    public String getSealType() {
        return sealType;
    }

    public void setSealType(String sealType) {
        this.sealType = sealType;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20251027.062237-321-sources.jar: com/ejianc/business/settlementmanage/vo/SettlementApplicationsealVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 总包结算书用印申请-主表
 *
 * @author generator
 *
 */
public class SettlementApplicationsealVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.String agentName; // 经办人
    private java.lang.String departmentName; // 部门
    private java.lang.String contractName; // 合同名称
    private java.lang.String constructionArea; // 建筑面积
    private java.math.BigDecimal contractPrice; // 合同造价
    private java.math.BigDecimal settlementValue; // 结算总额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date actualCommencementDate; // 实际开工日期
    private java.lang.String actualCommencementDateStr;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date actualCompletionDate; // 实际竣工日期
    private java.lang.String actualCompletionDateStr;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date applyTime; // 申请时间
    private java.lang.String documentsCode; // 单据编码
    private java.lang.String remarks; // 备注
    private java.lang.String organisation; // 所属组织
    private java.lang.Long agentId; // 经办人id
    private java.lang.Long agentDepartment; // 经办人部门
    private java.lang.Long contractId; // 合同id
    private java.lang.String phone; // 联系电话
    private java.lang.String createTimeShow; // 创建时间文本显示
    private java.lang.String billStateStr; // 单据状态Str
    private java.lang.Long originalId;
    private BigDecimal settlementSubmissionValue; // 结算报送值
    private BigDecimal settlementEstimateValue; // 结算预估值
    private BigDecimal estimatedCost; // 预计成本
    private BigDecimal profit; // 利润
    private BigDecimal profitRate; // 利润率
    private BigDecimal targetResponsibilityMargin; // 目标责任书利润率%
    private BigDecimal estimatedAccomplishTargetSituation; // 预计完成目标情况%
    private String sealCause; // 用印事由
    private BigDecimal sealFrequency; // 用印次数
    private BigDecimal sealCopies; // 用印份数
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date outDate; // 借出日期
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date returnDate; // 归还日期
    private String companySeal; // 公司章
    private String legalSeal; // 法人代表章
    private String contractSeal; // 合同专用章
    private String partySeal; // 党委章
    private String  disciplineSeal; // 纪委章
    private String otherSeal; // 其他章
    private String sealMemo; // 其他章备注
    private String sealLend; // 印章借出
    private String sealType; // 印章种类
    private String appendixIncome; // 项目收入成本总体概况
    private String appendixCommitment; // 用印承诺
    private String appendixInventory; // 用印清单
    private Integer tableNum; // 每份xx个表

    public Integer getTableNum() {
        return tableNum;
    }

    public void setTableNum(Integer tableNum) {
        this.tableNum = tableNum;
    }

    public String getAppendixIncome() {
        return appendixIncome;
    }

    public void setAppendixIncome(String appendixIncome) {
        this.appendixIncome = appendixIncome;
    }

    public String getAppendixCommitment() {
        return appendixCommitment;
    }

    public void setAppendixCommitment(String appendixCommitment) {
        this.appendixCommitment = appendixCommitment;
    }

    public String getAppendixInventory() {
        return appendixInventory;
    }

    public void setAppendixInventory(String appendixInventory) {
        this.appendixInventory = appendixInventory;
    }

    public BigDecimal getSettlementSubmissionValue() {
        return settlementSubmissionValue;
    }

    public void setSettlementSubmissionValue(BigDecimal settlementSubmissionValue) {
        this.settlementSubmissionValue = settlementSubmissionValue;
    }

    public BigDecimal getSettlementEstimateValue() {
        return settlementEstimateValue;
    }

    public void setSettlementEstimateValue(BigDecimal settlementEstimateValue) {
        this.settlementEstimateValue = settlementEstimateValue;
    }

    public BigDecimal getEstimatedCost() {
        return estimatedCost;
    }

    public void setEstimatedCost(BigDecimal estimatedCost) {
        this.estimatedCost = estimatedCost;
    }

    public BigDecimal getProfit() {
        return profit;
    }

    public void setProfit(BigDecimal profit) {
        this.profit = profit;
    }

    public BigDecimal getProfitRate() {
        return profitRate;
    }

    public void setProfitRate(BigDecimal profitRate) {
        this.profitRate = profitRate;
    }

    public BigDecimal getTargetResponsibilityMargin() {
        return targetResponsibilityMargin;
    }

    public void setTargetResponsibilityMargin(BigDecimal targetResponsibilityMargin) {
        this.targetResponsibilityMargin = targetResponsibilityMargin;
    }

    public BigDecimal getEstimatedAccomplishTargetSituation() {
        return estimatedAccomplishTargetSituation;
    }

    public void setEstimatedAccomplishTargetSituation(BigDecimal estimatedAccomplishTargetSituation) {
        this.estimatedAccomplishTargetSituation = estimatedAccomplishTargetSituation;
    }

    public String getSealCause() {
        return sealCause;
    }

    public void setSealCause(String sealCause) {
        this.sealCause = sealCause;
    }

    public BigDecimal getSealFrequency() {
        return sealFrequency;
    }

    public void setSealFrequency(BigDecimal sealFrequency) {
        this.sealFrequency = sealFrequency;
    }

    public BigDecimal getSealCopies() {
        return sealCopies;
    }

    public void setSealCopies(BigDecimal sealCopies) {
        this.sealCopies = sealCopies;
    }

    public Date getOutDate() {
        return outDate;
    }

    public void setOutDate(Date outDate) {
        this.outDate = outDate;
    }

    public Date getReturnDate() {
        return returnDate;
    }

    public void setReturnDate(Date returnDate) {
        this.returnDate = returnDate;
    }

    public String getCompanySeal() {
        return companySeal;
    }

    public void setCompanySeal(String companySeal) {
        this.companySeal = companySeal;
    }

    public String getLegalSeal() {
        return legalSeal;
    }

    public void setLegalSeal(String legalSeal) {
        this.legalSeal = legalSeal;
    }

    public String getContractSeal() {
        return contractSeal;
    }

    public void setContractSeal(String contractSeal) {
        this.contractSeal = contractSeal;
    }

    public String getPartySeal() {
        return partySeal;
    }

    public void setPartySeal(String partySeal) {
        this.partySeal = partySeal;
    }

    public String getDisciplineSeal() {
        return disciplineSeal;
    }

    public void setDisciplineSeal(String disciplineSeal) {
        this.disciplineSeal = disciplineSeal;
    }

    public String getOtherSeal() {
        return otherSeal;
    }

    public void setOtherSeal(String otherSeal) {
        this.otherSeal = otherSeal;
    }

    public String getSealMemo() {
        return sealMemo;
    }

    public void setSealMemo(String sealMemo) {
        this.sealMemo = sealMemo;
    }

    public String getSealLend() {
        return sealLend;
    }

    public void setSealLend(String sealLend) {
        this.sealLend = sealLend;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")

    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer

    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人
     */

    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 部门
     */
    public java.lang.String getDepartmentName() {
        return departmentName;
    }

    /**
     * 部门
     */
    public void setDepartmentName(java.lang.String departmentName) {
        this.departmentName = departmentName;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }

    public String getConstructionArea() {
        return constructionArea;
    }

    public void setConstructionArea(String constructionArea) {
        this.constructionArea = constructionArea;
    }

    /**
     * 合同造价
     */
    public java.math.BigDecimal getContractPrice() {
        return contractPrice;
    }

    /**
     * 合同造价
     */
    public void setContractPrice(java.math.BigDecimal contractPrice) {
        this.contractPrice = contractPrice;
    }
    /**
     * 结算总额
     */
    public java.math.BigDecimal getSettlementValue() {
        return settlementValue;
    }

    /**
     * 结算总额
     */
    public void setSettlementValue(java.math.BigDecimal settlementValue) {
        this.settlementValue = settlementValue;
    }
    /**
     * 实际开工日期
     */
    public java.util.Date getActualCommencementDate() {
        return actualCommencementDate;
    }

    /**
     * 实际开工日期
     */
    public void setActualCommencementDate(java.util.Date actualCommencementDate) {
        this.actualCommencementDate = actualCommencementDate;
    }
    /**
     * 实际竣工日期
     */
    public java.util.Date getActualCompletionDate() {
        return actualCompletionDate;
    }

    /**
     * 实际竣工日期
     */
    public void setActualCompletionDate(java.util.Date actualCompletionDate) {
        this.actualCompletionDate = actualCompletionDate;
    }
    /**
     * 申请时间
     */
    public java.util.Date getApplyTime() {
        return applyTime;
    }

    /**
     * 申请时间
     */
    public void setApplyTime(java.util.Date applyTime) {
        this.applyTime = applyTime;
    }
    /**
     * 单据编码
     */
    public java.lang.String getDocumentsCode() {
        return documentsCode;
    }

    /**
     * 单据编码
     */
    public void setDocumentsCode(java.lang.String documentsCode) {
        this.documentsCode = documentsCode;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 所属组织
     */
    public java.lang.String getOrganisation() {
        return organisation;
    }

    /**
     * 所属组织
     */
    public void setOrganisation(java.lang.String organisation) {
        this.organisation = organisation;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人部门
     */
    @ReferSerialTransfer(referCode="idm-dept")

    public java.lang.Long getAgentDepartment() {
        return agentDepartment;
    }

    /**
     * 经办人部门
     */
    @ReferDeserialTransfer

    public void setAgentDepartment(java.lang.Long agentDepartment) {
        this.agentDepartment = agentDepartment;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-incontract")

    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer

    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 联系电话
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系电话
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }

    public String getActualCommencementDateStr() {
        return actualCommencementDateStr;
    }

    public void setActualCommencementDateStr(String actualCommencementDateStr) {
        this.actualCommencementDateStr = actualCommencementDateStr;
    }

    public String getActualCompletionDateStr() {
        return actualCompletionDateStr;
    }

    public void setActualCompletionDateStr(String actualCompletionDateStr) {
        this.actualCompletionDateStr = actualCompletionDateStr;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }

    public String getSealType() {
        return sealType;
    }

    public void setSealType(String sealType) {
        this.sealType = sealType;
    }
}
